@@ -36,7 +36,7 @@ setMethod(
     adegtot <- adegpar(object@adeg.par)
     
     ## change default for some parameters
-    if((is.null(object@adeg.par$plabels$boxes$draw) & adegtot$plabels$optim) || (is.null(object@adeg.par$plabels$boxes$draw) & length(labels) > 1000)) ## dessin des boxes labels non renseigne par l'utilisateur lors de lappel a factorise
+    if((is.null(object@adeg.par$plabels$boxes$draw) & adegtot$plabels$optim) || (is.null(object@adeg.par$plabels$boxes$draw) & length(labels) > 1000))
       adegtot$plabels$boxes$draw <- FALSE
     if(is.null(object@adeg.par$porigin$include) & (any(names(object@g.args) %in% c("Sp", "nbobject"))))
       adegtot$porigin$include <- FALSE
@@ -71,7 +71,7 @@ s.label <- function(dfxy, labels = rownames(dfxy), xax = 1, yax = 2, facets = NU
   ## evaluation of some parameters
   thecall <- .expand.call(match.call())
   df <- try(as.data.frame(eval(thecall$dfxy, envir = sys.frame(sys.nframe() + pos))), silent = TRUE)
-  if((class(df) == "try-error") | is.null(thecall$dfxy)) ## non convenient dfxy argument
+  if(inherits(df, "try-error") | is.null(thecall$dfxy)) ## non convenient dfxy argument
     stop("non convenient selection for dfxy (can not be converted to dataframe)")
   
   ## parameters sorted
